# Django Rest Framework CLI

A usefull cli tool that creates and manages a Django Rest Framework project.

## Contents

-   [Installation](#Installation)
-   [Commands](#commands)
-   [License](#license)

## Installation

You can install this package by using pip:
```
pip install skn-drf-cli
```

## Commands

### Init

You can initialize a new starter project using:
```
drf-cli init your-project-name
```
This will create a starter project and you can build on top of that.

## License

Everything inside this repository is [MIT licensed](https://github.com/shywn-mrk/drf-cli/blob/main/LICENSE).
